summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_db.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2017-04-20 07:49:56 +0200
committerChristian Grothoff <christian@grothoff.org>2017-04-20 07:49:56 +0200
commit487237381dc81c16878b2e3faaac37777b6dd7bf (patch)
tree542b1b8ed111ebba37c50febd07f24c2afbdeeb0 /src/exchange/taler-exchange-httpd_db.h
parentb0811dd868f24010329cf294a0fd2d28a0cfeae6 (diff)
downloadexchange-487237381dc81c16878b2e3faaac37777b6dd7bf.tar.gz
exchange-487237381dc81c16878b2e3faaac37777b6dd7bf.tar.bz2
exchange-487237381dc81c16878b2e3faaac37777b6dd7bf.zip
fix misc doxygen issues
Diffstat (limited to 'src/exchange/taler-exchange-httpd_db.h')
-rw-r--r--src/exchange/taler-exchange-httpd_db.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/exchange/taler-exchange-httpd_db.h b/src/exchange/taler-exchange-httpd_db.h
index d2a0168db..4d894cfb9 100644
--- a/src/exchange/taler-exchange-httpd_db.h
+++ b/src/exchange/taler-exchange-httpd_db.h
@@ -133,7 +133,7 @@ struct TEH_DB_MeltDetails
* @param session_hash hash code of the session the coins are melted into
* @param num_new_denoms number of entries in @a denom_pubs, size of y-dimension of @a commit_coin array
* @param denom_pubs array of public denomination keys for the refresh (?)
* @param coin_melt_details signatures and (residual) value of and information about the respective coin to be melted
* @param commit_coin 2d array of coin commitments (what the exchange is to sign
* once the "/refres/reveal" of cut and choose is done)
* @param transfer_pubs array of transfer public keys (what the exchange is
@@ -146,7 +146,7 @@ TEH_DB_execute_refresh_melt (struct MHD_Connection *connection,
const struct GNUNET_HashCode *session_hash,
unsigned int num_new_denoms,
const struct TALER_DenominationPublicKey *denom_pubs,
- const struct TEH_DB_MeltDetails *coin_melt_details,
+ const struct TEH_DB_MeltDetails *coin_melt_detail,
struct TALER_EXCHANGEDB_RefreshCommitCoin *const* commit_coin,
const struct TALER_TransferPublicKeyP *transfer_pubs);
@@ -133,7 +133,7 @@ struct TEH_DB_MeltDetails
* @param num_new_denoms number of entries in @a denom_pubs, size of y-dimension of @a commit_coin array
* @param denom_pubs array of public denomination keys for the refresh (?)
- * @param coin_melt_details signatures and (residual) value of and information about the respective coin to be melted
+ * @param coin_melt_detail signatures and (residual) value of and information about the respective coin to be melted
* @param commit_coin 2d array of coin commitments (what the exchange is to sign
* once the "/refres/reveal" of cut and choose is done)